@@ -20,35 +20,6 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 sub rx_observable;
 
-=pod
-
-    Q: When do we subscribe to all the sources?
-
-    A: At the beginning
-
-
-    Q: When does the subscriber receive a 'next' event?
-
-    A: When (a) all the sources have emitted at least one 'next' event
-        (even now, with this emission), and (b) an event is emitted
-
-
-    Q: When does the subscriber receive an 'error' event?
-
-    A: When any of the sources emits an error.
-
-
-    Q: When does the subscriber receive a 'complete'?
-
-    A: When all of the sources have emitted 'complete'.
-
-
-    Q: What happens when the user unsubscribes?
-
-    A: We unsubscribe from all of the sources.
-
-=cut
-
 sub rx_combine_latest {
     my ($sources) = @_;
 
@@ -77,7 +48,7 @@ sub rx_combine_latest {
                     delete $didnt_emit{$j};
 
                     if (!%didnt_emit) {
-                        $subscriber->{next}->(\@latest_values) if defined $subscriber->{next};
+                        $subscriber->{next}->([@latest_values]) if defined $subscriber->{next};
                     }
                 },
                 error            => $subscriber->{error},
@@ -91,7 +62,7 @@ sub rx_combine_latest {
             $source->subscribe($own_observer);
         }
 
-        return;
+        return \%own_subscriptions;
     });
 }
 
