@@ -12,9 +12,9 @@ use Scalar::Util 'reftype', 'refaddr';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    op_concat_map op_delay op_distinct_until_changed op_distinct_until_key_changed op_exhaust_map op_filter op_first
-    op_map op_map_to op_merge_map op_multicast op_pairwise op_ref_count op_scan op_share op_start_with op_switch_map
-    op_take op_take_until op_take_while op_tap
+    op_concat_map op_debounce_time op_delay op_distinct_until_changed op_distinct_until_key_changed op_end_with
+    op_exhaust_map op_filter op_first op_map op_map_to op_merge_map op_multicast op_pairwise op_pluck op_ref_count
+    op_scan op_share op_start_with op_switch_map op_take op_take_until op_take_while op_tap
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -96,6 +96,57 @@ sub op_concat_map {
     };
 }
 
+my $_debounce_empty = {};
+
+sub op_debounce_time {
+    my ($due_time) = @_;
+
+    my ($timer_sub, $cancel_timer_sub) = get_timer_subs;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my @value_to_emit;
+            my $id;
+
+            my $own_subscription = RxPerl::Subscription->new;
+            my $own_observer = {
+                new_subscription => $own_subscription,
+                next     => sub {
+                    my @value = @_;
+
+                    @value_to_emit = @value ? @value : $_debounce_empty;
+
+                    $cancel_timer_sub->($id);
+                    $id = $timer_sub->($due_time, sub {
+                        undef @value_to_emit;
+                        $subscriber->{next}->(@value) if defined $subscriber->{next};
+                    });
+                },
+                error    => sub {
+                    $cancel_timer_sub->($id);
+                    $subscriber->{error}->(@_) if defined $subscriber->{error};
+                },
+                complete => sub {
+                    if (@value_to_emit) {
+                        $cancel_timer_sub->($id);
+                        @value_to_emit = () if _eqq($value_to_emit[0], $_debounce_empty);
+                        $subscriber->{next}->(@value_to_emit);
+                    }
+                    $subscriber->{complete}->();
+                },
+            };
+
+            $source->subscribe($own_observer);
+
+            return ($own_subscription, sub { $cancel_timer_sub->($id) });
+        });
+    }
+}
+
 sub op_delay {
     my ($delay) = @_;
 
@@ -198,6 +249,19 @@ sub op_distinct_until_key_changed {
     }),
 }
 
+sub op_end_with {
+    my (@values) = @_;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_concat(
+            $source,
+            rx_of(@values),
+        );
+    }
+}
+
 sub op_exhaust_map {
     my ($observable_factory) = @_;
 
@@ -432,6 +496,46 @@ sub op_pairwise {
     };
 }
 
+sub op_pluck {
+    my (@keys) = @_;
+
+    croak 'List of properties cannot be empty,' unless @keys;
+
+    return sub {
+        my ($source) = @_;
+
+        return rx_observable->new(sub {
+            my ($subscriber) = @_;
+
+            my $own_subscriber = {
+                %$subscriber,
+                next => sub {
+                    my (@value) = @_;
+
+                    if (! @value) {
+                        $subscriber->{next}->() if defined $subscriber->{next};
+                        return;
+                    }
+
+                    my $cursor = $value[0];
+                    foreach my $key (@keys) {
+                        if ((reftype($cursor) // '') eq 'HASH' and exists $cursor->{$key}) {
+                            $cursor = $cursor->{$key};
+                        } else {
+                            $subscriber->{next}->(undef) if defined $subscriber->{next};
+                            return;
+                        }
+                    }
+
+                    $subscriber->{next}->($cursor) if defined $subscriber->{next};
+                },
+            };
+
+            $source->subscribe($own_subscriber);
+        });
+    };
+}
+
 sub op_ref_count {
     return sub {
         my ($source) = @_;
